diff --git a/configure.ac b/configure.ac
index cb470e4..f353d36 100644
--- a/configure.ac
+++ b/configure.ac
@@ -266,6 +266,13 @@ case "$host_os" in
 				   [Compiling for Linux platform])
 		AC_MSG_RESULT([Linux])
 	;;
+	*cygwin*)
+		AC_DEFINE_UNQUOTED([QB_CYGWIN], [1],
+				   [Compiling for Cygwin platform])
+		ac_cv_link_attribute_section=no
+		ac_cv_atomic_need_memory_barrier=no
+		AC_MSG_RESULT([Cygwin])
+	;;
 	darwin*)
 		AC_DEFINE_UNQUOTED([QB_DARWIN], [1],
 				   [Compiling for Darwin platform])
diff --git a/include/qb/qbloop.h b/include/qb/qbloop.h
index 377e638..9f09c7e 100644
--- a/include/qb/qbloop.h
+++ b/include/qb/qbloop.h
@@ -239,7 +239,7 @@ int32_t qb_loop_poll_del(qb_loop_t *l, int32_t fd);
  *
  * @param l pointer to the loop instance
  * @param p the priority
- * @param signal (SIGHUP or SIGINT) etc ....
+ * @param sig (SIGHUP or SIGINT) etc ....
  * @param data user data passed into the dispatch function
  * @param dispatch_fn callback function
  * @param handle (out) a reference to the signal job
@@ -247,7 +247,7 @@ int32_t qb_loop_poll_del(qb_loop_t *l, int32_t fd);
  */
 int32_t qb_loop_signal_add(qb_loop_t *l,
 			   enum qb_loop_priority p,
-			   int32_t signal,
+			   int32_t sig,
 			   void *data,
 			   qb_loop_signal_dispatch_fn dispatch_fn,
 			   qb_loop_signal_handle *handle);
@@ -257,7 +257,7 @@ int32_t qb_loop_signal_add(qb_loop_t *l,
  *
  * @param l pointer to the loop instance
  * @param p the priority
- * @param signal (SIGHUP or SIGINT) etc ....
+ * @param sig (SIGHUP or SIGINT) etc ....
  * @param data user data passed into the dispatch function
  * @param dispatch_fn callback function
  * @param handle (in) a reference to the signal job
@@ -265,7 +265,7 @@ int32_t qb_loop_signal_add(qb_loop_t *l,
  */
 int32_t qb_loop_signal_mod(qb_loop_t *l,
 			   enum qb_loop_priority p,
-			   int32_t signal,
+			   int32_t sig,
 			   void *data,
 			   qb_loop_signal_dispatch_fn dispatch_fn,
 			   qb_loop_signal_handle handle);
diff --git a/lib/ipc_us.c b/lib/ipc_us.c
index c00c99c..68c5c1e 100644
--- a/lib/ipc_us.c
+++ b/lib/ipc_us.c
@@ -372,7 +372,7 @@ qb_ipcc_us_sock_connect(const char *socket_name, int32_t * sock_pt)
 	address.sun_len = QB_SUN_LEN(&address);
 #endif
 
-#if defined(QB_LINUX)
+#if defined(QB_LINUX) || defined(QB_CYGWIN)
 	snprintf(address.sun_path + 1, UNIX_PATH_MAX - 1, "%s", socket_name);
 #else
 	snprintf(address.sun_path, UNIX_PATH_MAX, "%s/%s", SOCKETDIR,
@@ -543,7 +543,7 @@ qb_ipcs_us_publish(struct qb_ipcs_service * s)
 #endif
 
 	qb_util_log(LOG_INFO, "server name: %s", s->name);
-#if defined(QB_LINUX)
+#if defined(QB_LINUX) || defined(QB_CYGWIN)
 	snprintf(un_addr.sun_path + 1, UNIX_PATH_MAX - 1, "%s", s->name);
 #else
 	{
@@ -575,7 +575,7 @@ qb_ipcs_us_publish(struct qb_ipcs_service * s)
 	 * Allow everyone to write to the socket since the IPC layer handles
 	 * security automatically
 	 */
-#if !defined(QB_LINUX)
+#if !defined(QB_LINUX) && !defined(QB_CYGWIN)
 	res = chmod(un_addr.sun_path, S_IRWXU | S_IRWXG | S_IRWXO);
 #endif
 	if (listen(s->server_sock, SERVER_BACKLOG) == -1) {
@@ -764,7 +764,7 @@ qb_ipcs_uc_recv_and_auth(int32_t sock, void *msg, size_t len,
 	struct msghdr msg_recv;
 	struct iovec iov_recv;
 
-#ifdef QB_LINUX
+#ifdef SO_PASSCRED
 	char cmsg_cred[CMSG_SPACE(sizeof(struct ucred))];
 	int off = 0;
 	int on = 1;
@@ -773,7 +773,7 @@ qb_ipcs_uc_recv_and_auth(int32_t sock, void *msg, size_t len,
 	msg_recv.msg_iovlen = 1;
 	msg_recv.msg_name = 0;
 	msg_recv.msg_namelen = 0;
-#ifdef QB_LINUX
+#ifdef SO_PASSCRED
 	msg_recv.msg_control = (void *)cmsg_cred;
 	msg_recv.msg_controllen = sizeof(cmsg_cred);
 #endif
@@ -786,7 +786,7 @@ qb_ipcs_uc_recv_and_auth(int32_t sock, void *msg, size_t len,
 
 	iov_recv.iov_base = msg;
 	iov_recv.iov_len = len;
-#ifdef QB_LINUX
+#ifdef SO_PASSCRED
 	setsockopt(sock, SOL_SOCKET, SO_PASSCRED, &on, sizeof(on));
 #endif
 
@@ -863,7 +863,7 @@ qb_ipcs_uc_recv_and_auth(int32_t sock, void *msg, size_t len,
 
 cleanup_and_return:
 
-#ifdef QB_LINUX
+#ifdef SO_PASSCRED
 	setsockopt(sock, SOL_SOCKET, SO_PASSCRED, &off, sizeof(off));
 #endif
 
diff --git a/lib/unix.c b/lib/unix.c
index f29b247..70ea461 100644
--- a/lib/unix.c
+++ b/lib/unix.c
@@ -80,7 +80,7 @@ qb_sys_mmap_file_open(char *path, const char *file, size_t bytes,
 	if (is_absolute) {
 		(void)strlcpy(path, file, PATH_MAX);
 	} else {
-#if defined(QB_LINUX)
+#if defined(QB_LINUX) || defined(QB_CYGWIN)
 		snprintf(path, PATH_MAX, "/dev/shm/%s", file);
 #else
 		snprintf(path, PATH_MAX, LOCALSTATEDIR "/run/%s", file);
